pub struct Upgrade {
pub owner: AccountId,
pub staging_duration: Duration,
pub staging_timestamp: Timestamp,
}This was removed because there is no standard (UIP) for upgradable contracts.
Fields
owner: AccountIdThis was removed because there is no standard (UIP) for upgradable contracts.
staging_duration: DurationThis was removed because there is no standard (UIP) for upgradable contracts.
staging_timestamp: TimestampThis was removed because there is no standard (UIP) for upgradable contracts.
Implementations